<?php $TRANSLATIONS = array(
"Export this ownCloud instance" => "Exportovať túto inštanciu ownCloud",
"This will create a compressed file that contains the data of this owncloud instance." => "Bude vytvorený komprimovaný archív s dátami owncloud inštancie.",
"Please choose the export type:" => "Vybrať typ exportu:",
"ownCloud system files" => "ownCloud systémové súbory",
"Just user files" => "Iba súbory používateľov",
"Export" => "Export"
);
